==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/dataprotection/kotlin/inputs/CopyOnExpiryOptionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.dataprotection.kotlin.inputs

import com.pulumi.azurenative.dataprotection.inputs.CopyOnExpiryOptionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Copy on Expiry Option
 * @property objectType Type of the specific object - used for deserializing
 * Expected value is 'CopyOnExpiryOption'.
 */
public data class CopyOnExpiryOptionArgs(
    public val objectType: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.dataprotection.inputs.CopyOnExpiryOptionArgs> {
    override fun toJava(): com.pulumi.azurenative.dataprotection.inputs.CopyOnExpiryOptionArgs =
        com.pulumi.azurenative.dataprotection.inputs.CopyOnExpiryOptionArgs.builder()
            .objectType(objectType.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [CopyOnExpiryOptionArgs].
 */
@PulumiTagMarker
public class CopyOnExpiryOptionArgsBuilder internal constructor() {
    private var objectType: Output<String>? = null

    /**
     * @param value Type of the specific object - used for deserializing
     * Expected value is 'CopyOnExpiryOption'.
     */
    @JvmName("vkgdfeurvyokoiug")
    public suspend fun objectType(`value`: Output<String>) {
        this.objectType = value
    }

    /**
     * @param value Type of the specific object - used for deserializing
     * Expected value is 'CopyOnExpiryOption'.
     */
    @JvmName("nscjqytrkbmnuprq")
    public suspend fun objectType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.objectType = mapped
    }

    internal fun build(): CopyOnExpiryOptionArgs = CopyOnExpiryOptionArgs(
        objectType = objectType ?: throw PulumiNullFieldException("objectType"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/dataprotection/kotlin/inputs/CopyOnExpiryOptionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.dataprotection.kotlin.inputs

import com.pulumi.azurenative.dataprotection.inputs.CopyOnExpiryOptionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Copy on Expiry Option
 * @property objectType Type of the specific object - used for deserializing
 * Expected value is 'CopyOnExpiryOption'.
 */
public data class CopyOnExpiryOptionArgs(
    public val objectType: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.dataprotection.inputs.CopyOnExpiryOptionArgs> {
    override fun toJava(): com.pulumi.azurenative.dataprotection.inputs.CopyOnExpiryOptionArgs =
        com.pulumi.azurenative.dataprotection.inputs.CopyOnExpiryOptionArgs.builder()
            .objectType(objectType.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [CopyOnExpiryOptionArgs].
 */
@PulumiTagMarker
public class CopyOnExpiryOptionArgsBuilder internal constructor() {
    private var objectType: Output<String>? = null

    /**
     * @param value Type of the specific object - used for deserializing
     * Expected value is 'CopyOnExpiryOption'.
     */
    @JvmName("olbpsfqoddysktib")
    public suspend fun objectType(`value`: Output<String>) {
        this.objectType = value
    }

    /**
     * @param value Type of the specific object - used for deserializing
     * Expected value is 'CopyOnExpiryOption'.
     */
    @JvmName("xeidjsvsdabvttur")
    public suspend fun objectType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.objectType = mapped
    }

    internal fun build(): CopyOnExpiryOptionArgs = CopyOnExpiryOptionArgs(
        objectType = objectType ?: throw PulumiNullFieldException("objectType"),
    )
}
